@@ -1,8 +1,8 @@
-# DocFinderTab 0.5.0
-# (c) 2001-2004, Stefan H. Holek, stefan@epy.co.at
+# DocFinderTab 1.0.2
+# (c) 2001-2006, Stefan H. Holek, stefan@epy.co.at
 # http://zope.org/Members/shh/DocFinderTab
 # License: ZPL
-# Zope: 2.3-2.7
+# Zope: 2.6-2.10
 
 # Monkey patch wrapper around Dieter Maurer's DocFinder product
 # http://www.dieter.handshake.de/pyprojects/zope/DocFinder.html
@@ -13,12 +13,12 @@
 # in the first place.
 
 __doc__ = 'Add a Doc tab to all Zope objects'
-__version__ = '0.5.0'
+__version__ = '1.0.2'
 
 __refresh_module__ = 0
 
 from AccessControl.Permission import registerPermissions
-from Permissions import ViewDocPermission, ViewDocDefaultRoles
+from permissions import ViewDocPermission, ViewDocDefaultRoles
 
 def initialize(context):
     # Register the helpfile
@@ -29,6 +29,9 @@ def initialize(context):
     # Register our permission
     registerPermissions(((ViewDocPermission, (), ViewDocDefaultRoles),))
 
+# Apply the inspect module patch
+import patch_inspect
+
 # Apply the DocFinderTab patch
-import Patch
+import patch_zope
 
